@@ -11,7 +11,10 @@ module modepLightCounter
      !  
      real(4),allocatable:: pe(:) ! count p.e by scinti, Ceren, syn, tran, 
      !                        direct hit by charged ptcls. 
-     real(4),allocatable:: pet   !  sum of above pe.
+!     real(4),allocatable:: pet   !  sum of above pe.
+! Solaris accepts above but actual alloc/dealloc is not
+!        permited for single varialbe. stupid
+     real(4):: pet   !  
   end type photoel
 
   type photonc
