@@ -199,7 +199,7 @@ c        -----------
 c        =============
       endif
       end
-      subroutine epdrawCcylEdg(peri, n1, h, cent,  p, n)
+      subroutine epdrawCcylEdg(peri, n1, h, centin,  p, n)
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
@@ -209,7 +209,7 @@ c        =============
                                !  (circle or part of it, etc      )
       real*8 h    !i nuput. place of the surface height.
                   !   h=0 for floor, h> 0 for ceil.
-      record /epPos/ cent     ! center of the cut pos. (x,y) are used. 
+      record /epPos/ centin     ! center of the cut pos. (x,y) are used. 
       record /epPos/ p(*)     ! output. (x,y,z) to describe
                ! a surface which cuts the cyl-like object.  The 
                ! surface makes the right angle with the axis
@@ -218,8 +218,9 @@ c        =============
       integer n ! output. number of vertex put in p.
 
       integer i
+      record /epPos/ cent
 
-
+      cent=centin
       cent.z = h
 
       do i = 1, n1-1
