@@ -1,8 +1,8 @@
 #!/bin/bash
-work=/tmp/$USER/Work
-if [ $#  -lt  4 ] || [ $# -gt 7 ]; then
+work=Work
+if [ $#  -lt  4 ] || [ $# -gt 6 ]; then
 cat <<EOF
- Usage: ./showPairFunc.sh  media  E1 E2 step [norm func LPM]
+ Usage: ./showPairFunc.sh  media  E1 E2 step [norm func]
    This shows pair funciton (f=  dsigma/dk (mb) but
    the unit depend on norm )
    where k= Ek/(Eg-2me); Ek being the electron kinetic energy.
@@ -20,13 +20,9 @@ cat <<EOF
            4--> /cm
            5--> area normlization.  Integral (kmin,1) of dsigma/dk=1
     func:  Pair func by Tsai-->1; by Nelson-->2(default is 2)"
-    LPM:   f no LPM, t at H.E, LPM is considered(defatul is t).
 EOF
 exit
 fi
-
-mkdir -p $work
-
 lt=""   
 lw=2
 media=$1;  E1=$2; E2=$3; step=$4;
@@ -35,18 +31,13 @@ func=2
 if [ $# -ge 5 ]; then
     norm=$5
 fi
-if [ $# -ge 6 ]; then
+if [ $# -eq 6 ]; then
     func=$6
 fi
-if [ $# -eq 7 ]; then
-    LPM=$7
-else
-    LPM="t"
-fi
 # echo input: $media $nevent $E1 $E2 $step
 
-nbin=`awk  'END {nbin=int(log(E2*1.0001/E1)/log(10.)/step)+1;print nbin}'   E1=$E1 E2=$E2 step=$step /dev/null`
-Eg=$E1
+nbin=`awk  'END {nbin=int(log(E2/E1)/log(10.)/step)+1;print nbin}'   E1=$E1 E2=$E2 step=$step /dev/null`
+Ek=$E1
 
 rm -f $work/fpair.png
 rm -f $work/fpair*.func
@@ -57,20 +48,22 @@ if [ $? != 0 ]; then
     exit 1
 fi
 for f in $(seq 1 $nbin); do
-  echo ${f}-th energy=$Eg 
-  echo $norm $media $Eg $LPM | ./drawpair${func}.out >> $work/fpair${f}.func
+  echo ${f}-th energy=$Ek 
+
+  echo $norm $media $Ek t | ./drawpair${func}.out >> $work/fpair${f}.func
   echo " " >> $work/fpair${f}.func
-  Eg=`awk 'END {Eg=Eg*10.**step;print Eg}' Eg=$Eg step=$step /dev/null`
+  Ek=`awk 'END {Ek=Ek*10.**step;print Ek}' Ek=$Ek step=$step /dev/null`
 done
 
-echo "Eg=${E1}" > $work/gnuplot.com
+echo "Ek=${E1}" > $work/gnuplot.com
 echo "step=${step}"  >> $work/gnuplot.com
 echo "media=\"${media}\""  >> $work/gnuplot.com
 cat fpair0.gp >> $work/gnuplot.com
 
-echo " plot  \"$work/fpair1.func\" w l lw ${lw} ${lt}  " >> $work/gnuplot.com
+echo " plot  \"Work/fpair1.func\" w l lw ${lw} ${lt}  " >> $work/gnuplot.com
 for f in $(seq 2 $nbin); do
-   echo " rep  \"$work/fpair${f}.func\" w l lw ${lw} $lt " >> $work/gnuplot.com
+   echo " rep  \"Work/fpair${f}.func\" w l lw ${lw} $lt " >> $work/gnu\
+plot.com
 done
 cat fpair1.gp >> $work/gnuplot.com
 
