@@ -4,31 +4,29 @@
 #include "Zmass.h"
 #include "ZepTrackp.h"
 
-       type(epmedia):: media
+      record /epmedia/media
       integer i, io
       real*8 Ee, prob, Eg, path, Ek 
       character*30 file
-      character*24 name
-      real(4):: rhoc
-      integer  nevent, dummy, seed(2), posast
+      character*16 name
+      integer  nevent, dummy, seed(2)
 
-!      EpartialSC = 0.1  ! for test  ( Seltzer region max
-!                        is lowered to this Ee)
+c      EpartialSC = 0.1  ! for test  ( Seltzer region max
+c                        is lowered to this Ee)
       dummy = 9876531
       io = 10
       read(*, *) nevent, Ek, name, LPMeffect, Flpm
-      call epgetRhoc(name, name, rhoc)
-      file =  "../../../Data/Media/"//trim(name)
+      file = "../../../Data/Media/"//name 
       call cerrorMsg(file,  1)
 
       Ee = Ek + masele
       
       open(io, file=file, action='read' ) 
       call epReadTab(io, media)
-      media%rhoc = rhoc
 
-      write(0,*) '# "Eg/Ek" "log10(//)" "sampled path(r%l)" '//
-     *        ' " prob/r%l" "Ek"'    
+
+      write(0,*) '# "Eg/Ek" "log10(//)" "sampled path(r.l)" '//
+     *        ' " prob/r.l" "Ek"'    
       call  cmkSeed(dummy, seed)
       call rnd1i(seed) 
 
@@ -37,7 +35,6 @@
          call epBrSampE(media, Ee, Eg)
          write(*,'(1p,5g13.4)') Eg/Ek,
      *       log10(Eg/Ek), path, prob, Ek
-         
       enddo
       end
 
