@@ -8,15 +8,20 @@
         data  Tcoef/5.d0/
         data  Tmin/1.d-3/
         data  EdepdEdx/.true./
+        data  HowQuench/1/
+	data  TargetElecBrems/0/
         data  TimeStruc/.false./
         data  Moliere/1/
-	data  AutoEmin /1/  
+	data  AutoEmin /2/  
         data  EminElec/611.d-6/
         data  EminGamma/100.d-6/
+        data  EpartialSC/10./
+        data  Flpm/1./
         data  EminH/0./               ! will be set max(5MeV,KEmin)
         data  ElowerBndPair/2.d-3/
         data  EupperBndCS/100.d-3/
-        data  IncGp/1/
+!        data  IncGp/4/
+        data  HowNormBrems/-1/
         data  Trace/.false./
         data  TraceErg/0., 1.d12, 0., 1.d12, 0.,1.d12/
         data  FreeC/.true./
@@ -36,6 +41,6 @@
         data  MagPair/0/
 	data  StoppingPw /1/
 	data  SrimEmax /0.09d0/
-        data  PhitsXs /0/
-        data  JamXs /0/
+!        data  PhitsXs /0/
+!        data  JamXs /0/
         end
