@@ -1,6 +1,5 @@
 !             position vector
-       type epPos 
-       sequence
+      structure /epPos/
 !       union
 !       map
         real*8 x, y, z  !  x,y,z in cm
@@ -12,4 +11,4 @@
 !        real(8)::r(3)
 !       endmap
 !      end union
-       end type epPos
+      end structure
