@@ -8,7 +8,19 @@
           real*8  Excom1        !  <100GeV;   use XCOM data for compton/p.e effect
           real*8  Excom2        !  < 100GeV;  use XCOM data for pair xsec.
           logical EdepdEdx      ! use energy dependent dE/dx
-                                !  F is used to compare analytic calc.
+                                !  F is used to compare analytic calc
+          integer:: HowQuench   ! R: dE/dx restricted
+	  !     F: dE/dx Full.  D delta ray contribution
+          !                     O other // (knot known).
+          !  cf: exprimetally obained quenching coef.
+          ! ecf: quenching factor for R. D+O has no quenching
+	  !  ecf*R + D + O = cf*F; D=F-R
+          !  ecf + F/R -1 + O/R = cf*F/R; then
+          !  ecf = 1 + (cf-1)F/R - O/R ; set O= 0 for first approx.
+          !   if  HowQuench = 0  use cf for ecf (equiv. to  v <=9.154
+          !   if            = 1  default:  use ecf as if old cf
+	  integer TargetElecBrems ! Flag to include target electron
+  	   !    brems 0->not bit 1->mu  bit2 p,pi,K (bit3 heavy?)
           logical LPMeffect     !  T(default). LPM is effective else off 
           logical TimeStruc     !  
 c          logical Moliere       ! Moliere's scattering  or  Gaussian
@@ -20,16 +32,29 @@ c          logical Moliere       ! Moliere's scattering  or  Gaussian
 	  real*8  EminH         ! Emin of Hadron/mu K.E/n 
                                 ! (except for anti p,n )
                                 ! if =0, max( 5 MeV, KEmin)
+          real*8 Flpm         !  Ee > Flpm*BremEminLPM is the
+                              !  actual LPM region
+          integer HowNormBrems ! -1 (default) : normalization base 
+                    !is C.S
+  		    ! 0: no normalization
+    	            ! 1: base is Seltzer & Berger at 10GeV
+          real*8 EpartialSC  ! default 10 (GeV)
+               ! Seltzer to Tsai partial screening transition
+  	       ! is made at this energy. (but normalization
+	       ! is done always at 10GeV)
+  	       ! Must be 100e-3 to 10 (GeV).  Around 1 GeV
+               ! Selzter and Tsai gap is large for light media.
           real*8 ElowerBndPair  ! Pair creation is neglected for Eg< this E
           real*8 EupperBndCS    ! Compton scattering is neglected Eg> this E
-          integer IncGp         ! Include gp interactions or not.  This is copied to 
-            !       HowPhotoP which means
-            !   integer HowPhotoP      !2  if 0--> no photo hadron prod.
-            !   1--> Sofia at all E
-            !   2--> Exp. data < 2.5 GeV ; Sofia > 2.5GeV
-            !   3--> Sofia < 2.5GeV;  (rho, omega, phi) or pi0 or pi+/- at current model
-            !   4--> Exp. data < 2.5GeV   //
-                               
+
+          integer IncGp  ! Include gp interactions or not.  This is copied from 
+!            !       HowPhotoP which means
+!            !   integer HowPhotoP      !2  if 0--> no photo hadron prod.
+!            !   1--> Sofia at all E
+!            !   2--> Exp. data < 2.5 GeV ; Sofia > 2.5GeV
+!            !   3--> Sofia < 2.5GeV;  (rho, omega, phi) or pi0 or pi+/- at current model
+!            !   4--> Exp. data < 2.5GeV   //
+
           logical Trace         ! how to take trace info.
           real*8 TraceErg(6)    ! a,b,c,d,e,f; energy range of trace particles 
                                 ! (a, b), (c,d), (e,f) GeV are target region
@@ -113,20 +138,23 @@ c          logical Moliere       ! Moliere's scattering  or  Gaussian
                                ! knockon > RecoilKEmin.  We explicitly
                                ! generate such high energy recoil.
                                ! default is 0.09 GeV/n 
-        integer::PhitsXs 	! 0-->
-                                ! 
-        integer::JamXs        ! 0--> only inelastic channel with Cosmos cross-section
-    			      ! 1--> use total cross-section with //
+!    PhitsXs is not used.  JamXs is managed by Cosmos
+!        integer::PhitsXs 	! 0--> 
+!                                ! 
+!        integer::JamXs        ! 0--> only inelastic channel with Cosmos cross-section
+!    			      ! 1--> use total cross-section with //
 
         common /epTrackC/ TraceErg,
      *  Bxu,  Byu,  Bzu, Exu, Eyu, Ezu,
      *  DtMax, Tcoef, Tmin, KEmin,
-     *  EminElec,  EminGamma, EminH, EupperBndCS, IncGp,
+     *  EminElec,  EminGamma, EminH, EupperBndCS,  IncGp,
+     *  HowNormBrems, TargetElecBrems,
      *  Trace,  FreeC, EpsLeng, SyncLoop,
-     *  ElowerBndPair, RecoilKEmin,
+     *  ElowerBndPair, RecoilKEmin, Flpm, EpartialSC,
      *  Eanihi, Ecut, Escat, Eabsorb, Excom1, Excom2,
-     *  MagField,  ElecField, TimeStruc, EdepdEdx, Moliere, AngleB,
+     *  MagField,  ElecField, TimeStruc, EdepdEdx, HowQuench,
+     *   Moliere, AngleB,
      *  Photo, Knckon, ALateCor, Sync,  MuNI, MuBr, MuPr, MagPair,
-     *  LPMeffect, Light, StoppingPw, AutoEmin,  SrimEmax,
-     *  PhitsXs, JamXs
+     *  LPMeffect, Light, StoppingPw, AutoEmin,  SrimEmax
+!     *  PhitsXs, JamXs
 
