@@ -1,15 +1,15 @@
-       type(epDirec)::  DCInp
-       type(epPos)::   PosInp
+        record /epDirec/ DCInp
+        record /epPos/  PosInp
 
-        complex(8):: Xrange, Yrange, Zrange
+        complex*16 Xrange, Yrange, Zrange
 	real*8  E0Max
 	real*8 Hwhm, ProfR
-        complex(8)::  CosNormal
+        complex*16  CosNormal
         logical LogIr
         character*12 InputA
         character*8 InputP
 
-!             sepics common
+c             sepics common
          common /Zspc/ 
      3   InputA,  InputP
 
@@ -17,8 +17,8 @@
      1   DCInp, PosInp, CosNormal, 
      2   E0Max, Hwhm,  ProfR,  LogIr
 
-!
-! IoCont: fortran dev # for cont dataset.
-!
+c
+c IoCont: fortran dev # for cont dataset.
+c
 
 
