@@ -91,7 +91,7 @@
 
     integer:: ny
     complex(kind(0d0))::z0, expa, z1, z2
-    real(8)::p, q
+    real(8)::p, q, u
     integer :: jcon, i, j
 !////////////
 !    write(0, *) n
@@ -105,7 +105,10 @@
        ny = 0
 !         find xing point of a line, x=x0,  and each edge
        z0=cmplx( x0, y0)
-       expa = cmplx(0.d0, 1.d0)   ! exp(i pi/2)
+       call rndc(u)
+       u = u*6.28318530717958647692d0  ! 0< u <2pi
+       expa= exp( (0.d0, 1.d0)*u)   ! exp(i u)
+!       expa = cmplx(0.d0, 1.d0)   ! exp(i pi/2)
        do i = 1, n
           z1 = cmplx( xa(1,i), ya(1,i) )
           if( i == n ) then
