@@ -1,6 +1,7 @@
       subroutine eppush(aTrack)
       implicit none
-#include  "ZepTrack.h"
+c#include  "ZepTrack.h"
+#include  "ZepTrackv.h"
 #include  "ZepStack.h"
 #include  "ZsepManager.h"
 
@@ -9,21 +10,33 @@
       integer:: size
       integer i
       character(len=192)::stackdiskpath
+      if( Making1ry == 1 ) then
+         ! now 1ry is being stacked
+         Total1ryE =Total1ryE + aTrack.p.fm.p(4) -aTrack.p.mass
+      endif
 
       if(Stack_pos .ge. MaxStackSize) then
          if( DdiskNo == 0 ) then
            ! open direct access file in binary 
             DdiskNo = StackDiskFileNo
-            size= sizeof(aTrack) 
+            size= sizeof(aTrack)   ! in bytes
             if(StackDiskFile == "scratch" ) then
                open(DdiskNo,  status="scratch",
      *           form="unformatted", access="direct",
+#if !defined Solaris
      *           recordsize=size)   
+#else
+     *           RECL=size)   
+#endif
             else
                call cgetfname(StackDiskFile, stackdiskpath)
                open(DdiskNo,  file=stackdiskpath,
      *           form="unformatted", access="direct",
+#if !defined Solaris
      *           recordsize=size)   
+#else
+     *           RECL=size)   
+#endif
             endif
             write(0,*) 'memory stack area=',MaxStackSize
             write(0,*) ' is not enought so that direct '
@@ -55,6 +68,8 @@ c///////////////////
          Stack(Stack_pos) = aTrack
       endif
       end  subroutine eppush
+
+
    !       ************************
    !        put 1ptcl in the stack area (for unknown cn)
    !       if stack overflows, disk is automatically used.
