@@ -13,6 +13,7 @@ c <<<<<<<<<<<<<<<<<<<<<light
 #include "ZepTrackv.h"
 #include "Zcnfig.h"
 
+
       integer:: cmpn      ! component#
       integer::modi ! modifier index
 c         when a particle moves  to a new component
@@ -21,6 +22,7 @@ c         the following must be done
       EminGamma =  Det.cmp(cmpn).EminG
       EminElec  =  Det.cmp(cmpn).EminE
       RecoilKEmin = Det.cmp(cmpn).RecoilE
+      call epSetTcut(Media(MediaNo),  RecoilKEmin ) ! v9.154
       KEmin =  KEminsave
       EminH = Enminsave
       ImperativeEmin = .false.
@@ -41,3 +43,17 @@ c            EminH = Enminsave
          endif
       endif
       end
+      subroutine  epSetTcut(media, RecoilKEmin)  ! 9.154
+      implicit none
+#include "Zmedia.h"      
+      real(8),intent(in):: RecoilKEmin  ! recoil KE min GeV
+      !      for histrical reason, media.sh.tcut and sh.w0 are
+!      used for dEdx calculations;  Det.cmp(cn).recoilE 
+!          should be directly used in better prog.
+      record /epmedia/ media  !out.   media of current component
+                    !  media.sh.tcut and w0 are set
+      media.sh.tcut = RecoilKEmin  ! GeV
+      media.sh.w0  = RecoilKEmin*1000.d0 ! MeV 
+      call epResetUrban( media, media.urb)
+      end
+
