@@ -21,27 +21,26 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-!
-!         interface to read configuration data for "fpolygon"
-!
-       type(Component)::  comp   ! output. to recieve the config data.
-!           read fpolygon data as 'new-*'
-!           fpolygon  has height and npoly vertex  attributes and the direction cosines
-!           of the 'x' and 'y'==> (1-6)
-!
+c
+c         interface to read configuration data for "fpolygon"
+c
+      record /Component/ comp   ! output. to recieve the config data.
+c           read fpolygon data as 'new-*'
+c           fpolygon  has height and npoly vertex  attributes and the direction cosines
+c           of the 'x' and 'y'==> (1-6)
+c
       integer i,  j
-      character(len=MAX_STRUCCHR):: basename 
-!             next is mandatory
+c             next is mandatory
       call eprpst(comp, 0, 0, 1, 6)
       call epfpolygonCnst(comp)  ! this call, xmin etc  in Volat
                               ! are undefined.
-      j = comp%vol + 3
+      j = comp.vol + 3
       xmin=  Volat( j )
       xmax = Volat( j )
       ymin = Volat( j+1 )
       ymax = Volat( j+1)
 
-      j = comp%vol + 3
+      j = comp.vol + 3
       do i = 2, npoly*2, 2
          if(xmin > Volat( j+i) ) xmin = Volat(j+i)
          if(xmax < Volat( j+i) ) xmax = Volat(j+i)
@@ -53,9 +52,13 @@
       Volat( j+1 ) = ymin
       Volat( j+2 ) = xmax
       Volat( j+3 ) = ymax
-      call epGetBaseStrucName(comp%struc, basename)
-      if( basename /= 'fpolygon' ) then
-         write(0,*) 'structure=',comp%struc, ' not usable'
+
+      if( comp.struc == 'fpolygon' .or.
+     *    comp.struc == 'fpolygon_xy'     ) then
+      elseif( comp.struc == 'fpolygon_yz' ) then
+      elseif( comp.struc == 'fpolygon_zx' ) then
+      else
+         write(0,*) 'structure=',comp.struc, ' not usable'
          stop
       endif
       end   subroutine eprfpolygon
@@ -65,27 +68,27 @@
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
-!
-!         interface to read configuration data for "fpolygon"
-!
-       type(Component)::  comp   ! output. to recieve the config data.
+c
+c         interface to read configuration data for "fpolygon"
+c
+      record /Component/ comp   ! output. to recieve the config data.
       integer::j
-!           check some values
-!      if( Compnum /= comp.cn ) then  ! this is dangerous.
-!                        since diff. comp. may get same cn.
-!                        at the time of config reading
-      if( Compnum /= comp%vol ) then   ! while comp.vol is uniq
-         npoly = Volat( comp%vol + 1)
-         height = Volat( comp%vol + 2)
-!         Compnum = comp.cn
-         Compnum = comp%vol
+c           check some values
+c      if( Compnum /= comp.cn ) then  ! this is dangerous.
+c                        since diff. comp. may get same cn.
+c                        at the time of config reading
+      if( Compnum /= comp.vol ) then   ! while comp.vol is uniq
+         npoly = Volat( comp.vol + 1)
+         height = Volat( comp.vol + 2)
+c         Compnum = comp.cn
+         Compnum = comp.vol
          if( npoly<=2 .or. height<=0 ) then
             write(0,*) ' npoly=',npoly, ' for fpolygon '
             write(0,*) ' height=', height
             write(0,*) ' some of above invalid'
             stop
          endif
-         j = comp%vol+ 3  + npoly*2 
+         j = comp.vol+ 3  + npoly*2 
          xmin = Volat( j ) 
          ymin = Volat( j+1 )
          xmax = Volat( j+2 ) 
@@ -102,17 +105,17 @@
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-!
-!        find length to the boundary of 'comp' from 'pos'
-!        with direction cos 'dir'
-!     'pos' and 'dir' are given in this 'comp' local coordinate.
-! 
+c
+c        find length to the boundary of 'comp' from 'pos'
+c        with direction cos 'dir'
+c     'pos' and 'dir' are given in this 'comp' local coordinate.
+c 
  
 
-       type(Component):: comp    ! input. you can extract volume parameters
+      record /Component/comp    ! input. you can extract volume parameters
                           !            by Volat( comp.vol + 1), etc
-       type(epPos)::  posl       ! input.  position.
-       type(epDirec)::  dirl      ! input. direction cosinse
+      record /epPos/ posl       ! input.  position.
+      record /epDirec/ dirl      ! input. direction cosinse
 
       real(8):: el                !  output length cm from pos to the boundary
       integer:: icon              ! output 0: el obtained. pos    is inside
@@ -134,37 +137,37 @@
       call epbfpolygon0(comp, cposl, cdirl, el, icon)
       end subroutine epbfpolygon
 
-!      **********************************
+c      **********************************
       subroutine epsfpolygon(comp, pos, icon)
       use fpolygon
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-!
-!           judge if a given 'pos' is inside 'comp'
-!         
-       type(Component)::  comp !input component
-       type(epPos)::  pos  ! input. position in  local coord.
+c
+c           judge if a given 'pos' is inside 'comp'
+c         
+      record /Component/ comp !input component
+      record /epPos/ pos  ! input. position in  local coord.
       integer icon  ! output. 0--> pos is inside
                     !         1-->        outside
-       type(epPos)::  cpos
+      record /epPos/ cpos
 
 
       call epv2c_fpolygon(comp, pos, cpos)
       call epsfpolygon0(comp, cpos, icon)
       end subroutine epsfpolygon
-!      **********************************
+c      **********************************
       subroutine epsfpolygon0(comp, pos, icon)
       use fpolygon
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-!
-!           judge if a given 'pos' is inside 'comp'
-!         
-       type(Component)::  comp !input component
+c
+c           judge if a given 'pos' is inside 'comp'
+c         
+      record /Component/ comp !input component
 !      record /epPos/ pos  ! input. position; canonical
       real(8),intent(in):: pos(3)
       integer,intent(out):: icon  ! output. 0--> pos is inside
@@ -181,7 +184,7 @@
          icon = 1
          return
       else
-         j = comp%vol + 3
+         j = comp.vol + 3
         call kinout2(Volat(j),2, Volat(j+1),2,
      *    npoly, pos(1), pos(2), inside)
 !         call kinout(Volat(j),2, Volat(j+1),2,
@@ -202,33 +205,33 @@
       endif
       end subroutine epsfpolygon0
 
-!     **************************************
+c     **************************************
       subroutine epenvlpfpolygon(comp, org, abc)
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-!
-!        give the envloping box of the component
-!
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  org       ! output.  origin of the enveloping box
+c
+c        give the envloping box of the component
+c
+      record /Component/ comp  ! input.   component.
+      record /epPos/ org       ! output.  origin of the enveloping box
                                !          in local coord. 
-       type(ep3Vec)::  abc      ! output.  a,b,c of the box
+      record /ep3Vec/ abc      ! output.  a,b,c of the box
 
       real(8):: temp, temp2
       call epenvlpfpolygon0(comp, org, abc)
       call epc2v_fpolygon(comp, abc, abc)
       end subroutine epenvlpfpolygon
 
-!    *************************************
+c    *************************************
       subroutine epatlocfpolygon(comp, loc)
       use fpolygon
       implicit none
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 
-       type(Component)::  comp ! input.
+      record /Component/ comp ! input.
       integer loc(*)
  
       integer i
@@ -251,14 +254,14 @@
 #include "ZepDirec.h"
 #include "Zepdebug.h"
 
-!
-!        find length to the boundary of 'comp' from 'pos'
-!        with direction cos 'dir'
-!     'pos' and 'dir' are given in this 'comp' local coordinate.
-! 
+c
+c        find length to the boundary of 'comp' from 'pos'
+c        with direction cos 'dir'
+c     'pos' and 'dir' are given in this 'comp' local coordinate.
+c 
  
 
-       type(Component):: comp    ! input. you can extract volume parameters
+      record /Component/comp    ! input. you can extract volume parameters
                           !            by Volat( comp.vol + 1), etc
       real(8),intent(in):: posl(3)     ! input.  position.
       real(8),intent(in):: dirl(3)     ! input. direction cosinse
@@ -287,7 +290,7 @@
          x = el * dirl(1) + posl(1)
          y = el * dirl(2) + posl(2)
          ! see if it is inside upper flat polygon
-         call kinout2(Volat(comp%vol+3),2,  Volat(comp%vol+4),2,
+         call kinout2(Volat(comp.vol+3),2,  Volat(comp.vol+4),2,
      *   npoly, x, y, inside)
 !         j = comp.vol+3
 !         call kinout(Volat(j),2, Volat(j+1),2,
@@ -311,7 +314,7 @@
          x = el * dirl(1) + posl(1)
          y = el * dirl(2) + posl(2)
          ! see if it is inside lower flat polygon
-         call kinout2(Volat(comp%vol+3),2,  Volat(comp%vol+4),2,
+         call kinout2(Volat(comp.vol+3),2,  Volat(comp.vol+4),2,
      *   npoly, x, y, inside)
 !         j = comp.vol+3
 !         call kinout(Volat(j),2, Volat(j+1),2,
@@ -360,7 +363,7 @@
             el = ( height-posl(3) ) /dirl(3)         
             x = el*dirl(1) + posl(1)
             y = el*dirl(2) + posl(2)
-            call kinout2(Volat(comp%vol+3),2,  Volat(comp%vol+4),2,
+            call kinout2(Volat(comp.vol+3),2,  Volat(comp.vol+4),2,
      *           npoly, x, y, inside)
 !            j = comp.vol+3
 !            call kinout(Volat(j),2, Volat(j+1),2,
@@ -374,7 +377,7 @@
             el = -posl(3)/dirl(3)
             x = el*dirl(1) + posl(1)
             y = el*dirl(2) + posl(2)
-            call kinout2(Volat(comp%vol+3),2, Volat(comp%vol+4),2,
+            call kinout2(Volat(comp.vol+3),2, Volat(comp.vol+4),2,
      *           npoly, x, y, inside)
 
 !            j = comp.vol+3
@@ -403,7 +406,7 @@
 
 !          seee side wall
  
-       type(Component):: comp    ! input. you can extract volume parameters
+      record /Component/comp    ! input. you can extract volume parameters
                           !            by Volat( comp.vol + 1), etc
       real(8),intent(in):: posl(3)     ! input.  position.
       real(8),intent(in):: dirl(3)     ! input. direction cosinse
@@ -418,7 +421,7 @@
       integer i, j, jcon, kcon
       real(8),parameter::eps2=2.d-5
 
-      j = comp%vol + 2
+      j = comp.vol + 2
       p2(1) = Volat(j+1)
       p2(2) = Volat(j+2)
       p2(3) = 0.d0
@@ -452,7 +455,7 @@
 
 !!!          near the boundary, next sometimes  fials
 !!!       call kxplvsq(posl, dirl, p1, p2, height, el, jcon)
-!//////////////
+c//////////////
 !         if(mydebug) then
 !            write(0,*) 'after kxplvsq : H=', height, i
 !            write(0,*) 'posl=',posl(:)
@@ -461,7 +464,7 @@
 !            write(0,*) 'p2=', p2(:)
 !            write(0,*) ' jcon, el=',jcon, el
 !         endif
-!///////////////
+c///////////////
 !!         if(jcon == 0 ) then
          if( kcon <= 4 .and. el > 0.d0) then
             if(elmin > el ) then
@@ -485,7 +488,7 @@
             ! the particle is outsied and no X-ing point
             ! When the incident is vertical, this apts to happen.
             !
-!!!            posinside = 1
+c!!            posinside = 1
 
 !           if(mydebug) then
 !             write(0,*) 'posl =',posl(:)
@@ -505,7 +508,7 @@
          icon = -1
       endif
       end subroutine ep_fpolygon_side
-!     **************************************
+c     **************************************
       subroutine epenvlpfpolygon0(comp, org, abc)
       use fpolygon
       implicit none
@@ -513,13 +516,13 @@
 #include "Zcnfig.h"
 #include "ZepPos.h"
 
-!
-!        give the envloping box of the component
-!
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  org       ! output.  origin of the enveloping box
+c
+c        give the envloping box of the component
+c
+      record /Component/ comp  ! input.   component.
+      record /epPos/ org       ! output.  origin of the enveloping box
                                !          in local coord. 
-       type(ep3Vec)::  abc      ! output.  a,b,c of the box
+      record /ep3Vec/ abc      ! output.  a,b,c of the box
 
 
       call epfpolygonCnst(comp)  ! for safety 
@@ -537,26 +540,25 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  posv     ! input
-       type(epPos)::  posc     ! output can be posv
+      record /Component/ comp  ! input.   component.
+      record /epPos/ posv     ! input
+      record /epPos/ posc     ! output can be posv
 
-       type(epPos)::  temp
+      record /epPos/ temp
 
       call epfpolygonCnst(comp)
-      if( comp%struc  == 'fpolygon' .or. 
-     *    comp%struc  == 'fpolygon_w' ) then
+      if( comp.struc  == 'fpolygon' ) then
          posc = posv
-      elseif( comp%struc(1:11)  == 'fpolygon_xy' ) then
+      elseif( comp.struc  == 'fpolygon_xy' ) then
          posc = posv
-      elseif( comp%struc(1:11) == "fpolygon_yz" ) then
-         temp =epPos(posv%y, posv%z, posv%x)
+      elseif( comp.struc == "fpolygon_yz" ) then
+         temp =epPos(posv.y, posv.z, posv.x)
          posc = temp
-      elseif( comp%struc(1:11) == "fpolygon_zx" ) then
-         temp = epPos( posv%z, posv%x, posv%y)
+      elseif( comp.struc == "fpolygon_zx" ) then
+         temp = epPos( posv.z, posv.x, posv.y)
          posc = temp 
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epbfpolygon is invalid'
          stop
       endif
@@ -571,31 +573,30 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepPos.h"
-       type(Component)::  comp  ! input.   component.
-       type(epPos)::  posc     ! input
-       type(epPos)::  posv     ! output (can be posc)
+      record /Component/ comp  ! input.   component.
+      record /epPos/ posc     ! input
+      record /epPos/ posv     ! output (can be posc)
 
-       type(epPos)::  temp    !
+      record /epPos/ temp    !
 
       call epfpolygonCnst(comp)
-      if( comp%struc  == 'fpolygon' .or.
-     *    comp%struc  == 'fpolygon_w'  ) then
+      if( comp.struc  == 'fpolygon' ) then
          posv = posc
-      elseif( comp%struc(1:11)  == 'fpolygon_xy' ) then
+      elseif( comp.struc  == 'fpolygon_xy' ) then
          posv = posc
-      elseif( comp%struc(1:11) == "fpolygon_yz" ) then
+      elseif( comp.struc == "fpolygon_yz" ) then
 !                X:y   Y:z    Z:x
-         temp = epPos( posc%z, posc%x, posc%y)
+         temp = epPos( posc.z, posc.x, posc.y)
 !!         posc = temp !!!!!!!!!!!! aho
          posv = temp
-      elseif( comp%struc(1:11) == "fpolygon_zx" ) then
+      elseif( comp.struc == "fpolygon_zx" ) then
 !         cpos = epPos( pos.z, pos.x, pos.y)
 !                  X:z    Y:x          Z:y
-         temp = epPos(posc%y, posc%z, posc%x)
+         temp = epPos(posc.y, posc.z, posc.x)
 !!         posc = temp  !!!!!!!!!! aho
          posv = temp  
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epbfpolygon is invalid'
          stop
       endif
@@ -607,27 +608,26 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepDirec.h"
-       type(Component)::  comp  ! input.   component.
-       type(epDirec)::  dirv     ! input
-       type(epDirec)::  dirc     ! output  can be dirv
+      record /Component/ comp  ! input.   component.
+      record /epDirec/ dirv     ! input
+      record /epDirec/ dirc     ! output  can be dirv
  
-       type(epDirec)::  temp
+      record /epDirec/ temp
      
       call epfpolygonCnst(comp)
 
-      if( comp%struc  == 'fpolygon' .or.
-     *    comp%struc  == 'fpolygon_w' ) then
+      if( comp.struc  == 'fpolygon' ) then
          dirc = dirv
-      elseif( comp%struc(1:11)  == 'fpolygon_xy' ) then
+      elseif( comp.struc  == 'fpolygon_xy' ) then
          dirc = dirv
-      elseif( comp%struc(1:11) == "fpolygon_yz" ) then
-         temp = epDirec(dirv%y, dirv%z, dirv%x)
+      elseif( comp.struc == "fpolygon_yz" ) then
+         temp = epDirec(dirv.y, dirv.z, dirv.x)
          dirc = temp
-      elseif( comp%struc(1:11) == "fpolygon_zx" ) then
-         temp = epDirec(dirv%z, dirv%x, dirv%y)
+      elseif( comp.struc == "fpolygon_zx" ) then
+         temp = epDirec(dirv.z, dirv.x, dirv.y)
          dirc = temp
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epbfpolygon is invalid'
          stop
       endif
@@ -640,29 +640,28 @@
 #include "Zep3Vec.h"
 #include "Zcnfig.h"
 #include "ZepDirec.h"
-       type(Component)::  comp  ! input.   component.
-       type(epDirec)::  dirc     ! input
-       type(epDirec)::  dirv     ! output can be dirc
+      record /Component/ comp  ! input.   component.
+      record /epDirec/ dirc     ! input
+      record /epDirec/ dirv     ! output can be dirc
 
-       type(epDirec)::  temp
+      record /epDirec/ temp
 
       call epfpolygonCnst(comp)
 !           (X,Y,Z)<---(x,y,z)
-      if( comp%struc  == 'fpolygon' .or.
-     *    comp%struc  == 'fpolygon_w') then
+      if( comp.struc  == 'fpolygon' ) then
          dirv = dirc
-      elseif( comp%struc(1:11)  == 'fpolygon_xy' ) then
+      elseif( comp.struc  == 'fpolygon_xy' ) then
          dirv = dirc
-      elseif( comp%struc(1:11) == "fpolygon_yz" ) then
+      elseif( comp.struc == "fpolygon_yz" ) then
 !         cdir = epDirec(dir.y, dir.z, dir.x)  X:y  Y:z  Z:x
-         temp = epDirec(dirc%z, dirc%x, dirc%y) 
+         temp = epDirec(dirc.z, dirc.x, dirc.y) 
          dirv = temp   
-      elseif( comp%struc(1:11)  == 'fpolygon_zx' ) then
+      elseif( comp.struc  == 'fpolygon_zx' ) then
 !         cdir = epDirec(dir.z, dir.x, dir.y)  X:z Y:x Z:y
-         temp = epDirec(dirc%y, dirc%z, dirc%x) 
+         temp = epDirec(dirc.y, dirc.z, dirc.x) 
          dirv = temp
       else
-         write(0,*) ' comp%struc=', comp%struc,
+         write(0,*) ' comp.struc=', comp.struc,
      *      ' to epbfpolygon is invalid'
          stop
       endif
