@@ -151,9 +151,11 @@ c  &&&&         convert to canonial one
       record /epPos/ posc ! output. 
       record /Component/ comp
       if( comp.struc == "torus_x") then
-         posc = epPos( posv.z, posv.y, posv.x)
+c         posc = epPos( posv.z, posv.y, posv.x)
+         posc = epPos( posv.y, posv.z, posv.x)
       elseif(comp.struc == "torus_y") then
-         posc = epPos( posv.x, posv.z, posv.y)
+c         posc = epPos( posv.x, posv.z, posv.y)
+         posc = epPos( posv.z, posv.x, posv.y)
       else
          posc = posv
       endif
@@ -167,9 +169,11 @@ c  &&&&         convert to canonial one
       record /epPos/ posv ! output. 
       record /Component/ comp
       if( comp.struc == "torus_x") then
-         posv = epPos( posc.z, posc.y, posc.x)
+c         posv = epPos( posc.z, posc.y, posc.x)
+         posv = epPos( posc.z, posc.x, posc.y)
       elseif(comp.struc == "torus_y") then
-         posv = epPos( posc.x, posc.z, posc.y)
+c         posv = epPos( posc.x, posc.z, posc.y)
+         posv = epPos( posc.y, posc.z, posc.x)
       else
          posc = posv
       endif
@@ -183,9 +187,10 @@ c  &&&&         convert to canonial one
       record /epPos/ dirc ! output. 
       record /Component/ comp
       if( comp.struc == "torus_x") then
-         dirc = epPos( dirv.z, dirv.y, dirv.x)
+c         dirc = epPos( dirv.z, dirv.y, dirv.x)
+         dirc = epPos( dirv.y, dirv.z, dirv.x)
       elseif(comp.struc == "torus_y") then
-         dirc = epPos( dirv.x, dirv.z, dirv.y)
+         dirc = epPos( dirv.z, dirv.x, dirv.y)
       else
          dirc = dirv
       endif
@@ -199,9 +204,10 @@ c  &&&&         convert to canonial one
       record /epPos/ dirv ! output. 
       record /Component/ comp
       if( comp.struc == "torus_x") then
-         dirv = epPos( dirc.z, dirc.y, dirc.x)
+c         dirv = epPos( dirc.z, dirc.y, dirc.x)
+         dirv = epPos( dirc.z, dirc.x, dirc.y)
       elseif(comp.struc == "torus_y") then
-         dirv = epPos( dirc.x, dirc.z, dirc.y)
+         dirv = epPos( dirc.y, dirc.z, dirc.x)
       else
          dirv = dirc
       endif
@@ -229,12 +235,16 @@ c  &&&&         convert to canonial one
       NVTX = 0
       if(comp.struc == "torus_y") then
          call epc2v_torus(comp, org, org)
-         temp = abc.y
-         abc = ep3Vec(abc.x, abc.z, temp)
+!         temp = abc.y
+c         abc = ep3Vec(abc.x, abc.z, temp)
+!         abc = ep3Vec(temp, abc.z, abc.x)
+         call epc2v_torus(comp, abc, abc)
       elseif(comp.struc == "torus_x") then
          call epc2v_torus(comp, org, org)
-         temp=abc.x
-         abc = ep3Vec(abc.z, abc.y, temp)
+!         temp=abc.x
+c         abc = ep3Vec(abc.z, abc.y, temp)
+!         abc = ep3Vec(abc.z, temp, abc.y)
+         call epc2v_torus(comp, abc, abc)
       endif
       end
 
