@@ -65,7 +65,7 @@ module polyhedra0
   real(8),parameter::twopi = 2*pi
   logical,save::bugbug=.false.
   logical,save::bugbug2=.false.
-!ontains
+contains
  subroutine kxInPolyhedra0(p, q, n, x, inside)
    implicit none
    integer,intent(in)::n  ! number of points
@@ -125,6 +125,7 @@ module polyhedra0
    real(8):: v1(3), v2(3)
    integer:: i, i2, i3
    real(8):: ans, alpha, sumteta   
+   character(5):: condi
    integer:: icon, jcon
    if(n < 3 ) then
       write(0,*) &
