@@ -24,8 +24,10 @@ c
       integer i, cnxx, j, cnx, jcon
       record /epPos/postemp
       record /epDirec/ dirtemp
+      record /epTrack/ saveTrack
+      integer,save:: PrevNo
+      save saveTrack
 c          present comp, boundary
-
       call epbndry2(Cn, el, jcon)
       if(jcon .ne. 0) then
 c               No boundary found in the  present comp. strange.
@@ -35,49 +37,77 @@ c         etc and continue the execution.
 c         However, this also happens if a wrong incident direcion is given,
 c         too or by some unkown reason. So we count the occurence / event
 c         issue messages.
+         if( Bndryerr == 0 ) then
+            ! save pos and dir
+            saveTrack = cTrack
+            PrevNo = 0
+         endif
          Bndryerr = Bndryerr + 1    ! count it
+         PrevNo = PrevNo + 1
          call eppos2cn(Cn, cTrack, cnxx)
          if(cnxx .ge. Det.nct) then
             icon = 2
             return !  *******
          endif
-         call cerrorMsg(' ',  1)
-         call cerrorMsg(
+         if( Bndryerr < 10 ) then
+            call cerrorMsg(' ',  1)
+            call cerrorMsg(
      *    'If following message comes out at the very beginning of', 1)
-         call cerrorMsg(
+            call cerrorMsg(
      *    ' an event, better to suspect that your incident particle',1)
-         call cerrorMsg(
+            call cerrorMsg(
      *    'direction might be wrong; check it.!!!!!', 1)
-         call cerrorMsg(
+            call cerrorMsg(
      *    'If not,  a particle on or very near to a ', 1)
-         call cerrorMsg(
+            call cerrorMsg(
      *    'component boundary might have buffalloed Epics.' , 1) 
-         call cerrorMsg(
-     *    'Epics tries to recover the matter safely.', 1)
-         call cerrorMsg(
+            call cerrorMsg(
+     *    'Epics is expected to recover the matter safely.', 1)
+            call cerrorMsg(
      *    'However, some unknown cause may lead to this, ', 1)
-         call cerrorMsg(
+            call cerrorMsg(
      *    'so check the coordinate below, if they are very ',1)
-         call cerrorMsg(
-     *    'near to the boundary, it may be ok', 1)
-         write(msg, *) ' Cn for current pos=',Cn,
-     *           ' which should be ', cnxx
-         call cerrorMsg(msg, 1)
-         write(msg,*) ' x y z=', cTrack.pos.x, cTrack.pos.y,
-     *        cTrack.pos.z
-         call cerrorMsg(msg, 1)
-         write(msg,*) 'Move.Track.pos =', Move.Track.pos.x,
-     *        Move.Track.pos.y, Move.Track.pos.z
-         call cerrorMsg(msg, 1)
-         write(msg,*) 'cTrack wx.y,z=',cTrack.w.x,
-     *        cTrack.w.y, cTrack.w.z
-         call cerrorMsg(msg, 1)
-         write(msg,*) ' cTrack E=',cTrack.p.fm.p(4), ' Move E=',
-     *        Move.Track.p.fm.p(4),  ' code=',cTrack.p.code,
+            call cerrorMsg(
+     *      'near to the boundary, it will  be ok', 1)
+            call epfordebug('epbndry')
+            write(msg,*) 'NOTE: local above means local coordinate'
+            call cerrorMsg(msg, 1)
+            write(msg,*)
+     *      '  so  if component name has "_", it is different'
+            call cerrorMsg(msg, 1)
+            write(msg,*) '  from  canonical coordinate'
+            call cerrorMsg(msg, 1)
+            write(msg,*)
+     *      ' cTrack T.E=',cTrack.p.fm.p(4), ' Move TE=',
+     *           Move.Track.p.fm.p(4),  ' code=',cTrack.p.code,
      *      ' subcode=', cTrack.p.subcode,' chg=',cTrack.p.charge
-         call cerrorMsg(msg,1)
-         call cerrorMsg('-------------------------------',1)
-         if( Bndryerr  .gt. 100 ) then
+            call cerrorMsg(msg,1)
+            call cerrorMsg('-------------------------------',1)
+         endif
+         if( PrevNo  > 1 ) then
+            if( cTrack.p.code /= saveTrack.p.code .or.
+     *          cTrack.p.charge /= saveTrack.p.charge .or.
+     *          cTrack.p.subcode /= saveTrack.p.subcode ) then
+                prevNo = 0
+                saveTrack = cTrack
+             elseif( 
+     *          abs(cTrack.pos.x-saveTrack.pos.x) > EpsLeng .and.
+     *          abs(cTrack.pos.y-saveTrack.pos.y) > EpsLeng .and.
+     *          abs(cTrack.pos.z-saveTrack.pos.z) > EpsLeng  ) then
+                PrevNo = 0
+                saveTrack = cTrack
+             endif
+          endif
+          if( PrevNo > 10 ) then
+              ! hopeless to escape err; discard this
+             if( cTrack.p.fm.p(4) < Total1ryE* 1.d-4) then
+                icon = 2
+                return          !  *******
+             endif
+          endif
+             
+         if( Bndryerr  > 
+     *     min(500,  max(int(10*Total1ryE/100), 10)) ) then
             call cerrorMsg('too many boundary error', 0)
          endif
          if(Cn .ne. cnxx) then
@@ -91,9 +121,17 @@ c         issue messages.
             call epnewComp(cTrack)
          else
             pos = cTrack.pos
-            cTrack.pos.x = cTrack.pos.x - EpsLeng*cTrack.w.x
-            cTrack.pos.y = cTrack.pos.y - EpsLeng*cTrack.w.y
-            cTrack.pos.z = cTrack.pos.z - EpsLeng*cTrack.w.z
+              ! go back little bit
+!            cTrack.pos.x = cTrack.pos.x - EpsLeng*cTrack.w.x
+!            cTrack.pos.y = cTrack.pos.y - EpsLeng*cTrack.w.y
+!            cTrack.pos.z = cTrack.pos.z - EpsLeng*cTrack.w.z
+            dirtemp.x=1.
+            dirtemp.y=0.
+            dirtemp.z = 0.
+            call ctransVectZ(cTrack.w, dirtemp, dirtemp)
+            cTrack.pos.x = cTrack.pos.x - EpsLeng*dirtemp.x
+            cTrack.pos.y = cTrack.pos.y - EpsLeng*dirtemp.y
+            cTrack.pos.z = cTrack.pos.z - EpsLeng*dirtemp.z
          endif
          el = EpsLeng
          icon = 1
@@ -101,7 +139,8 @@ c         issue messages.
          CrossMode = 0
       else
          CrossMode = 0
-c          partial  container's boundary, if any, may be closer
+c         **** partial**** container's boundary,
+c               if any, may be closer
          do j = 1, Det.cmp(Cn).NPContainer
 c((((((((((
 c           cnx = Det.cmp(Cn).PContained(j)
@@ -115,10 +154,9 @@ c))))))))))))
                endif
             endif
          enddo
-c          Matreska may be in between
+c         *** Matreska *** may be in between
          do i = 1, Det.cmp(Cn).NMatreska
 c((((((((((((((((
-c           call epbndry2(Det.cmp(Cn).Contains(i),  tmpel, jcon)
             call epbndry2(CnArea( Det.cmp(Cn).Contains+i),  tmpel, jcon)
 c))))))))))
             if(jcon .eq. 1 .and. tmpel .lt. el) then
