@@ -10,7 +10,7 @@ c        *********************************************************
 c
       module moddedx
 c         work common block for dedx (GeV/g/cm2) (epEloss / epchcke)
-      real(8):: dedx  !  restricted dE/dx
+      real(8):: dedx  !  restricted dE/dx 
       real(8):: dedxf  ! full dE/dx
       end module moddedx
 
@@ -118,6 +118,8 @@ c                read configuration
 
 c     
        call eprcnf(dsn2)
+       call epiniXsMedia  ! make media info needed for H.I
+                           ! under Cosmos
 c      *********************
 c               init for nuclin, hadrin
 cc       call haddenC
@@ -151,7 +153,7 @@ c<<<<<<<<<<<<<<
           Efield.z = Ezu
        endif
 c
-c          fix tracedir 
+c          fix tracedir ; This must be before uiaev in future
        if(Trace) then
           if(TraceDir .eq. ' ') then
              call cgetLoginN(uid) ! cosmos function
@@ -166,6 +168,7 @@ c             init for 1 event
 #include "ZepManager.h"
 #include "ZepTrackp.h"
 #include "ZepTrackv.h"
+
        integer icon ! output. if  0,  user has set ptcl in stack
                    !             1,  no ptcl has set in stack
       character*200 msg
@@ -175,6 +178,11 @@ c             init for 1 event
       integer  klena, i
 
        Bndryerr = 0   ! counter for bundary search failures/ event
+       Making1ry = 1  ! Now preparing 1 event so 1ry is being made
+                    ! will be made to be 0 at epr1ev.
+                    ! If this is 1, partcles being stacked are 1ry
+                    ! we counts total energy of 1ry.
+       Total1ryE = 0. ! clear total 1ry K.E counter of the current event
        Cn=-1
        Firsti=.true.
        FirstC=.true.
@@ -182,6 +190,7 @@ c             init for 1 event
        FirstInt.x = -100000.d0
        FirstInt.y = -100000.d0
        FirstInt.z = -100000.d0
+       FirstCn = 0 
        FirstMedia.colElem = 0
 
 #if defined (INTINFO)
@@ -280,6 +289,7 @@ c           call cerrorMsg('no incident found in epr1ev', 0)
 c        endif
 c
         call uafi1ev            ! after init of 1 event
+        Making1ry = 0        
         end
 c      ****************************
 c                user dependent all event end
@@ -327,6 +337,17 @@ c             else
 c             endif
 !               info may be used only to set Move.Abort    
              call epLightPreUserde(info, cTrack)
+             if(Move.Abort /= 0 ) then
+                if(Move.Abort /= 3 ) then
+                   call  epempty ! empty the sack. discard ev.
+                   call  epSkipUpdateNo
+                else
+                   Move.Abort = 0
+                endif
+                icon = 1
+                goto 100
+             endif
+
           endif
 c          add  time  
          if(TimeStruc) then
@@ -395,7 +416,6 @@ c      endif
 c
 c                
        use modepRange, only:       attenF
-
       implicit none
 #include  "ZepManager.h"
 #include  "ZepTrackv.h"
@@ -431,7 +451,9 @@ c       care.
             Move.dl = 0.
             Move.dx = 0.
             Move.dt = 0.
-         elseif( AutoEmin == 2  .or. AutoEmin == 4 ) then
+         elseif(( AutoEmin == 2 .or. AutoEmin == 4 ) .or.
+     *     (cTrack.p.code == kphoton .and. !  for photon v9.154
+     *       AutoEmin == 3 ) ) then
 c             energy is low, see if the range is < el
             call epGetRange(MediaNo, Media(MediaNo), cTrack.p,
      *                      Rgm, Rcm)
@@ -740,28 +762,26 @@ c         for ibm
 
 c     **********************
       subroutine epNonEleMag
+      use modXsecMedia, xmedia=>media, xelement=>element
       implicit none
 #include "ZepTrackp.h"
 #include "ZepTrackv.h"
 #include "Zcode.h"
-c////////////////                                                              
-c      logical show
-c      common /showshow/ show
+c////////////////
+!      real(8):: pathp, pathb, pathn  
 c///////////       
       integer jcon
 c          sample interaction length for non-e/g
       real*8 prob, path, tokgpm2
 
-c          set cosmos condition(TrackBefMove, TargetMassN)
+c          set cosmos condition(TrackBefMove,
       tokgpm2 = Media(MediaNo).X0g *10.d0 ! r.l --> kg/m^2
-c                 target mass and Z; not used from v7.0
-c         but projectile is set. 
-c      call ep2cosCond(Media(MediaNo).Aeff, Media(MediaNo).Zeff)
+
       call ep2cosCond
       call cfixModel( cTrack.p )
       call ciniSmpIntL
 
-      call epsmpNEPIntL(Media(MediaNo))
+      call epsmpNEPIntL(xmedia(mediumNo))
 c         reset muon interaction conditions
       call ep2cosCondr
 c
@@ -773,8 +793,6 @@ c                add knock on
       endif
       if(cTrack.p.code .eq. kmuon) then
 c            add muon pair, brems, n.i if requested.
-c            this func for cosmos has been disabled  so that
-c            treate it here.
          if( Media(MediaNo).mu.MuPr .ge. 2 .and. 
      *       cTrack.p.fm.p(4) .gt.  Media(MediaNo).cnst.muPrEmin ) then
             call epmuPrsmpP(Media(MediaNo),
@@ -790,6 +808,9 @@ c               path is in r.l. convert  it to kg/m2
 c               path is in r.l. convert  it to kg/m2
             path = path*tokgpm2
             call csetIntInf(path, .false., 'brem')
+c//////////////
+c            pathb = path
+c/////////////
          endif
          if( Media(MediaNo).mu.MuNI  .ge. 2 .and.
      *       cTrack.p.fm.p(4) .gt.  Media(MediaNo).cnst.muNEmin ) then
@@ -820,27 +841,35 @@ c               path is in r.l. convert  it to kg/m2
 c     ******************
       subroutine epEloss
       use moddedx
+      use modGUI
       implicit none
 #include "ZepTrackp.h"
 #include "ZepTrackv.h"
 #include "Zcnfig.h"
 #include "Zcode.h"
-               
+
+      type(gui),save:: sinfo  ! for quenching
+      integer::modif
       integer k
       
       real*8  dx, up, dedxmu, dedlmu,
      *      s1, s2, scol2, schg2, sigma
-      real*8 cupsilon, csyncTELoss, cf
+      real*8 cupsilon, csyncTELoss, cf, qf, cff
+      real(8):: dEdxbyBrems, dEdxbyBremsf
+      real(8):: dEdlBrems, FbyR
       logical lowehvyion
       real(8),save::  dedl
       real(8):: dedxout, dedlout
-      integer::modif 
        !>>>>>>>>>>>>>>>light
       integer::epLightGetd  !  function for extracting d part from countDE
        !<<<<<<<<<<<<<<<<<
+      qf = 0.  ! quenching fraction. 
       k = cTrack.p.code
 c              compute energy loss rate
       if(EdepdEdx) then
+         dEdxbyBrems = 0.
+         dEdxbyBremsf = 0.
+         dEdlBrems = 0.
          lowehvyion  = .false.
          if(cTrack.p.fm.p(4) .le. cTrack.p.mass) then
             dedx = 0.
@@ -869,7 +898,12 @@ c                            dedx is in GeV/(g/cm^2)
                   call epdedxhvy(Media(MediaNo), cTrack.p, dedx,dedxf)
                else
                   call epdedxNone(Media(MediaNo), cTrack.p, dedx,dedxf)
+                  call epdedxTargetBrems(Media(MediaNo), cTrack.p, 
+     *               dEdxbyBrems, dEdxbyBremsf)
                endif
+
+
+
                if(cTrack.p.code .eq. kmuon) then
                   call epmudEdx(Media(MediaNo).mu.MuNI, 
      *                 Media(MediaNo).mu.MuBr, 
@@ -885,13 +919,32 @@ c                            dedx is in GeV/(g/cm^2)
 c                 below for test; use above  normally
 c            if( cTrack.p.charge >= 1) then ! ????
                modif = Det.cmp(Cn).modifier
+               sinfo%modif = modif
 !                   next Birks is for Talre, Birks or Log
-               if( modif > 0 .or.  Media(MediaNo).Birks /= ' ') then
+               if(modif > 0 .or.
+     *            Media(MediaNo).Birks /= ' ') then
 c                even if no quenching is specified in media file,
 c                modifier can  force quenching. inside of the next,
-c                kind is checed if really quenching is specified by modifier
-                  call epOrgCorrec( modif,
-     *              Media(MediaNo), cTrack.p, dedx, cf)
+c                kind is checked if really quenching is specified by modifier
+
+                  if( HowQuench == 0 )  then
+!                   employ cf as it is (same as old) "dedx" 
+                     call epOrgCorrec( modif,
+     *                    Media(MediaNo), cTrack.p, dedx, cf)
+                     qf= 1.0
+                  elseif( HowQuench >= 1 ) then
+                     call epOrgCorrec( modif,
+     *                    Media(MediaNo), cTrack.p, dedxf, cff)
+                     sinfo%dedx = dedx
+                     sinfo%dedxf = dedxf
+                     call epGUI(1, sinfo)
+                     cf = sinfo%cf
+                     qf = sinfo%qf
+                  else
+                     write(0,*) ' HowQuench=',HowQuench,
+     *               ' invalid '
+                     stop
+                  endif
                else
                   cf = 1.
                endif
@@ -903,6 +956,16 @@ c                kind is checed if really quenching is specified by modifier
      *         Media(MediaNo).rhoc
             dedlmu = dedxmu /Media(MediaNo).gtocm * ! GeV/cm
      *         Media(MediaNo).rhoc
+            if( btest(TargetElecBrems, 2)) then
+!                         this will overestimate for thin media
+               dEdlBrems = dEdxbyBremsf/Media(MediaNo).gtocm * 
+     *         Media(MediaNo).rhoc   
+            elseif( btest(TargetElecBrems, 0) .or.
+     *           btest(TargetElecBrems, 1)  ) then
+!                     this will underestimate
+               dEdlBrems = dEdxbyBrems/Media(MediaNo).gtocm * 
+     *         Media(MediaNo).rhoc   
+            endif
             if( abs( epLightGetd( Det.cmp(Cn).CountDE) ) .eq. 2) then
 c                Enery loss fluctuation; use  Urban model for singl charge
 c                 or  high energy
@@ -920,11 +983,15 @@ c                    Move.dEioni = GeV  in 'dl' cm
             else
                Move.dEioni = dedl * Move.dl
             endif
-            Move.dE = Move.dEioni + dedlmu*Move.dl  ! total loss
-            Move.dEeff = Move.dEioni * cf + dedlmu*Move.dl  ! effective loss
+
+            Move.dE = Move.dEioni + dedlmu*Move.dl  
+     *            + dEdlBrems*Move.dl  ! total loss without quenching
+            Move.dEeff = Move.dEioni *(qf* cf + (1-qf))
+     *            + dedlmu*Move.dl  
+     *            + dEdlBrems*Move.dl   ! effective loss with quenching
          endif
       else
-c            use constant energy loss at minimum ionization
+c            use constant energy loss at minimum ionization; actually not used
 c            In this case, knock-on process should be prohibitted  by
 c            giving large Tcut.   Birks etc correction not applied.
          dedx = Media(MediaNo).dEdxatp3m * cTrack.p.charge**2  ! GeV/(g/cm2)
@@ -963,7 +1030,7 @@ c          this will not happen if muon specific loss exists.
             dx = max(Move.dE/dedx, 0.d0)
             Move.Trunc=.true.
             Move.Cross = .false.   
-            Move.dEeff = Move.dE*cf
+            Move.dEeff = Move.dE*(cf*qf+(1.0-qf))
             Move.dEioni = Move.dE
          endif
 
@@ -982,29 +1049,6 @@ c          this will not happen if muon specific loss exists.
 
       SumDe = SumDe + Move.dE
       end
-      subroutine epStrange
-      implicit none
-#include "ZepTrackp.h"
-#include "ZepTrackv.h"
-#include "Zcnfig.h"
-#include "Zcode.h"
-
-      integer::k
-      integer,save::nstrange = 0
-      nstrange = nstrange + 1                  
-
-      k = cTrack.p.code
-      write(0,*) '|Z|>1 but not heavy: code,sub,chg='
-      write(0,*) k, cTrack.p.subcode, cTrack.p.charge
-      write(0,*) 'K.E=',cTrack.p.fm.p(4)-cTrack.p.mass
-      write(0,*) ' mass=',cTrack.p.mass
-      cTrack.p.fm.p(4)=cTrack.p.mass  ! make 0 energy
-      if(nstrange > 100 ) then
-         stop
-      endif
-      write(0,*) nstrange, ' times neglected'
-      end
-      
 c     ******************
       subroutine epTrace
 c     ******************
@@ -1093,6 +1137,7 @@ ccc      endif
        end
 c      ****************************************
        subroutine epprog
+       use modXsecMedia, xmedia=>media, xelement=>element
        implicit none
 c
 c     5     processes, i.e, pair creation, compton, Photo-electric
@@ -1101,11 +1146,12 @@ c      and Photo-production of pions are considered.
 c
 #include  "ZepTrackv.h"
 #include  "ZepTrackp.h"
+#include  "Zevhnv.h"
 
 c
       real*8 tcomp, tphot, tpair, tgp, tcoh,  t
       real*8 E, prob, xprob(5), txray(5)
-      real*8 xs
+      real*8 xs, mfp
       real*8  pairmfp, dl, dx, tmpair, u
       real*4  xsec(5)  !  coh, incoh,  P.E  1/(g/cm2)
 c      real*8  Excom1, Excom2  !now in ZepTrackp.h
@@ -1156,11 +1202,12 @@ c               below 1MeV, use accurate xs.
       else
          tpair=1.e35
       endif
-      if(IncGp > 0 .and. E .gt. 152.d-3) then
+      if(IncGp > 0 .and. E .gt. 153.d-3) then ! > 0.152431798977028
          call ep2cosCond
          call cfixModel( cTrack.p )
-         call cgpXsec(Media(MediaNo).A,  E, xs)    ! xs in mb
-         prob = xs*Media(MediaNo).mbtoPX0   ! prob/r.l
+         call cgetPhotoPxs(ActiveMdl2, cTrack.p, xmedia(mediumNo),
+     *      xs, mfp)
+         prob = xs*Media(MediaNo).mbtoPX0 ! prob/r.l
          call rndc(u)
          tgp = -log(u)/prob          ! sampled path in r.l
       else
@@ -1405,8 +1452,6 @@ c
       logical ok, kbtest, needdedx
       integer k
       real*8 ke
-      real*8 cf
-      integer modif
       integer,save::nstrange=0
 c////////////////                                                              
 c      logical show
@@ -1426,7 +1471,6 @@ c >>>>>>>>>>>>>>>>>>light
          return  ! *************
       endif
 c<<<<<<<<<<<<<<<<<<<<light
-      
       if(k .eq. kelec) then
           if(aTrack.p.charge .eq. -1) then
              ok=aTrack.p.fm.p(4) .gt. EminElec
@@ -1472,6 +1516,8 @@ c            can decay
       subroutine epAbsorb(aTrack, icon)
       use epModify
       use moddedx
+      use modUI
+      use modGUI
       implicit none
 #include "ZepTrackv.h"
 #include "ZepTrackp.h"
@@ -1485,18 +1531,24 @@ c            can decay
 
       logical ok, kbtest, needdedx
       integer k
-      real*8 ke
-      real*8 cf
-      integer modif
+      real*8 ke, qf
+      type(gui)::sinfo
+      integer::modif
+      real*8 cf, qg, cff
       integer,save::nstrange=0
 c////////////////                                                              
 c      logical show
 c      common /showshow/ show
 c///////////       
-
+      qf = 0.
       ke = aTrack.p.fm.p(4)- aTrack.p.mass
       k =  aTrack.p.code
       icon = 1
+
+      Move.dE= 0.
+      Move.dEeff= 0.
+      Move.dEioni = 0.
+
       if(k .eq. kelec) then
           if(aTrack.p.charge .eq. -1) then
              if(kbtest(Eabsorb, BitElectron)) then
@@ -1565,18 +1617,30 @@ c            can decay
                 if( aTrack.p.charge > 1  ) then
                    needdedx = Media(MediaNo).Birks /= ' '
                    modif = Det.cmp(Cn).modifier
+                   sinfo%modif = modif
                    if(.not. needdedx) then
-                      if(modif > 0 .and. allocated( modify) ) then
+                      if(modif > 0 .and.
+     *                   allocated( modify) ) then
                          needdedx =
-     *                        IBITS(modify( modif )%kind, bitQuench, 1)
-     *                        > 0  
+     *                        IBITS(modify( modif )%kind, bitQuench,
+     *                          1)  > 0  
                       endif
                       if(needdedx ) then
 c                        to get queching effect we need dedx
                          call epdedxhvy(Media(MediaNo), 
      *                   aTrack.p, dedx, dedxf)
-                         call epOrgCorrec(modif, 
-     *                     Media(MediaNo), aTrack.p, dedx, cf)
+                         if(HowQuench == 0 ) then
+                            call epOrgCorrec(modif, 
+     *                        Media(MediaNo), aTrack.p, dedx, cf)
+                         elseif( HowQuench >= 1 ) then
+                            call epOrgCorrec( modif,
+     *                    Media(MediaNo), cTrack.p, dedxf, cff)
+                            sinfo%dedx = dedx
+                            sinfo%dedxf = dedxf
+                            call epGUI(1, sinfo)
+                            cf =  sinfo%cf
+                            qf =  sinfo%qf
+                         endif
                       else
                          cf =1.0
                       endif
@@ -1585,7 +1649,7 @@ c                        to get queching effect we need dedx
                    endif
                    if( aTrack.p.charge /= 0  ) then  ! for safety
                       Move.dE = ke
-                      Move.dEeff = ke *cf
+                      Move.dEeff = ke *(cf*qf+ 1.-qf)
                       Move.dEioni= Move.dE  
                       SumDe = SumDe + Move.dE
                       call epLightPreUserde(1, aTrack)
@@ -1604,15 +1668,22 @@ c                        to get queching effect we need dedx
              endif
           endif
        endif
+
+
        if(Move.Abort .ne. 0) then
-          call epempty          ! empty the stack
-          call epSkipUpdateNo
+          if( Move.Abort == 3 ) then
+             Move.Abort = 0
+          else
+             call epempty       ! empty the stack
+             call epSkipUpdateNo
+          endif
           icon = 1
        endif
        end
       subroutine epchckE(aTrack, icon)
       use epModify
       use moddedx
+      use modGUI
       implicit none
 #include "ZepTrackv.h"
 #include "ZepTrackp.h"
@@ -1628,9 +1699,9 @@ c
       logical ok, kbtest, needdedx
       integer k
       real*8 ke
-      real*8 cf
-      integer modif
-      integer,save::nstrange=0
+      real*8 cf,qf,cff
+      type(gui):: sinfo
+      integer:: modif
 c////////////////                                                              
 c      logical show
 c      common /showshow/ show
@@ -1776,19 +1847,32 @@ c                endif                                <<<<<<<<<<<<<<<
                    if( aTrack.p.charge > 1  ) then
                       needdedx = Media(MediaNo).Birks /= ' '
                       modif = Det.cmp(Cn).modifier
+                      sinfo%modif = modif
                       if(.not. needdedx) then
-                         if(modif > 0 .and. allocated( modify) ) then
+                         if(modif > 0 .and.
+     *                      allocated( modify) ) then
                             needdedx =
-     *                      IBITS(modify( modif )%kind, bitQuench, 1)
-     *                       > 0  
+     *                      IBITS(modify(modif )%kind,
+     *                      bitQuench, 1) > 0  
                          endif
                       endif
                       if(needdedx ) then
 c                        to get queching effect we need dedx
                          call epdedxhvy(Media(MediaNo), 
      *                   aTrack.p, dedx, dedxf)
-                         call epOrgCorrec(modif, 
-     *                     Media(MediaNo), aTrack.p, dedx, cf)
+                         if( HowQuench == 0 ) then
+                            call epOrgCorrec(modif, 
+     *                       Media(MediaNo), aTrack.p, dedx, cf)
+                         elseif( HowQuench >= 1 ) then
+!                                next call is not needed now
+                            call epOrgCorrec( modif,
+     *                    Media(MediaNo), cTrack.p, dedxf, cff)
+                            sinfo%dedx = dedx
+                            sinfo%dedxf = dedxf
+                            call epGUI(1, sinfo)
+                            cf = sinfo%cf
+                            qf = sinfo%qf
+                         endif
                       else
                          cf =1.0
                       endif
@@ -1797,7 +1881,7 @@ c                        to get queching effect we need dedx
                    endif
                    if( aTrack.p.charge /= 0  ) then  ! for safety
                       Move.dE = ke
-                      Move.dEeff = ke *cf
+                      Move.dEeff = ke *(cf*qf+1.0-qf)
                       Move.dEioni= Move.dE  
                       SumDe = SumDe + Move.dE
                       call epLightPreUserde(1, aTrack)
@@ -1827,8 +1911,12 @@ c                endif                               <<<<<<<<<<<<
           icon=1
        endif
        if(Move.Abort .ne. 0) then
-          call epempty          ! empty the stack
-          call epSkipUpdateNo
+          if( Move.Abort /= 3 ) then
+             call epempty       ! empty the stack
+             call epSkipUpdateNo
+          else
+             Move.Abort = 0
+          endif
           icon = 1
        endif
        end
@@ -1888,6 +1976,7 @@ c                Move.Track.t= cTrack.t+1.e8  ! version <= 8.62
 c      ************************
        subroutine epint(icon)
        use modIntInfo
+       use modXsecMedia, xmedia=>media, xelement=>element
        implicit none
 #include  "ZepTrackv.h"
 #include  "ZepTrackp.h"
@@ -1908,9 +1997,9 @@ c      common /showshow/show
 c///////////////
 
       k = cTrack.p.code
-c         almost dummy setting 
-      ia =Media(MediaNo).A
-      iz =Media(MediaNo).Z
+!         almost dummy setting 
+!      ia =Media(MediaNo).A
+!      iz =Media(MediaNo).Z
 
 #if defined (INTINFO)
       kintInfo = min(k, maxcodeForInt)
@@ -1935,13 +2024,9 @@ c         almost dummy setting
          elseif(Move.proc .eq. 'photop') then
 c
             call ep2cosPtcl( cTrack.p )
-c              for small basic cross section case.
-            call epfixTarget2(ActiveMdl, Media(MediaNo))
-            call ep2cosCond2(Media(MediaNo).colA, Media(MediaNo).colZ,
-     *          Media(MediaNo).colXs)
-c            call epInfoPhotoP( IncGp )  ! inform how to treat gp  
-c                             moved to onepath routine (after epicsfile is read
-c                             call this)
+            call cfixTarget(xmedia(mediumNo)) ! 
+            call epcpTargetInfo  ! cp target info 
+            call ep2cosCond2  !  
             call cphotop        ! Cosmos function
             call eppushPtcl(cTrack)  ! use pos. info from this ptcl
          elseif(Move.proc .eq. 'mpair') then
@@ -1992,16 +2077,21 @@ c                             call this)
 
             call epNEPknoc
 
-         elseif(cTrack.p.code .eq. kmuon .and. 
-     *        Move.proc .ne. 'decay') then
-            if(Move.proc .eq.'pair') then
+         elseif(cTrack.p.code .eq. kmuon ) then
+            if( Move.proc == 'decay') then
+               call ep2cosPtcl( cTrack.p ) ! set
+               call ep2coscond2            ! Move.Track
+               call cinteMuon  ! capture is also treated
+                           !   don't use nuc. interaction there
+            elseif(Move.proc .eq.'pair') then
                call epmuInte
             elseif(Move.proc .eq.'brem') then
                call epmuInte
             elseif(Move.proc .eq.'nuci') then
                call epmuInte
             endif
-         else
+         else  
+            ! hadronic ptcls
             call ep2cosPtcl( cTrack.p )
 c            if(  k == kmuon .and. cTrack.p.charge == -1  .and.
 c     *           cTrack.p.fm.p(4) <= cTrack.p.mass*1.001) then
@@ -2010,16 +2100,9 @@ c                 for decay of stopping mu-,
 c                 we must fix target for capture case; really captured
 c                 or decay  is determined in cinteMuon; 
 
-            if(  k == kmuon ) then
-c                 altough next is used only for negative stoppingmuons  
-c                 we call next for all muons so that epfixTarget
-c                 can be called by all muons.
-               call epgetCaprate( Media(MediaNo) ) ! equiv. to epgetXsec
-            endif
-
-            call epfixTarget(ActiveMdl, Media(MediaNo))
-            call ep2cosCond2(Media(MediaNo).colA,
-     *           Media(MediaNo).colZ,  Media(MediaNo).colXs)
+            call cfixTarget(xmedia(mediumNo))
+            call epcpTargetInfo ! cp target info 
+            call ep2cosCond2 
             call cinteNEP       ! cosmos eppp
             call eppushPtcl( cTrack )
          endif
@@ -2059,9 +2142,11 @@ c                   ielastic/decay so  regard as 1st interaction
             FirstC=.false.
          endif
          if(.not. FirstC) then
+!            the interaction was recognized as the first one
             call epl2w(cTrack.cn, FirstInt, temppos)
             FirstInt = temppos
             FirstMedia = Media(MediaNo)
+            firstCn = cTrack.cn
             if(Light == 21 ) then
                call epLightIOwrite1stCol
             endif
@@ -2078,7 +2163,20 @@ c                   ielastic/decay so  regard as 1st interaction
 
       icon = 1
       end
-
+      subroutine epcpTargetInfo    
+!       copy target info in xmedia to Epics Media
+      use modXsecMedia, only: TargetNucleonNo, TargetProtonNo,
+     *  TargetXs, colElemNo
+      implicit none
+#include  "ZepTrackv.h"
+#include  "ZepTrackp.h"
+#include  "Zcode.h"
+#include  "Zevhnv.h"
+      Media(MediaNo).colA = TargetNucleonNo
+      Media(MediaNo).colZ = TargetProtonNo
+      Media(MediaNo).colXs = TargetXs
+      Media(MediaNo).colElem = colElemNo
+      end 
 c     ******************
       subroutine epcoher
 c        coherent scattering
@@ -2282,6 +2380,16 @@ c            energy absorbed by atom is Eabs = Eshell= Eg-(Ee-Me)
 c                  regard it as deposited in the media
 c          if(Det.cmp(Cn).CountDE .ge. 1) then >>>>>>>>>>>>>>light
              call epLightPreUserde(1, cTrack)
+             if( Move.Abort /= 0 ) then
+                if( Move.Abort /=3 ) then
+                   call epempty ! empty the stack
+                   call epSkipUpdateNo
+                else
+                   Move.Abort=0
+                endif
+                  ! no flag is needed. since called from epint
+                return
+             endif
 c          endif                               <<<<<<<<<<<<<
           Exray = 0.
        else
@@ -2657,95 +2765,6 @@ c       approximate one.
          r = 1.d10
       endif
       end
-c////////////////////////////
-      subroutine debugm(msg)
-      implicit none
-#include "ZepTrackv.h"
-      character*(*) msg
-      logical strange
-      character*16 trigger
-
-      strange = .false.
-      if( Media(MediaNo).noOfElem .le. 0 .or. 
-     *    Media(MediaNo).noOfElem .gt. 5 ) then
-         strange = .true.
-         trigger='noOfElem'
-      elseif(Media(MediaNo).A .lt. 1. .or.
-     *   Media(MediaNo).A .gt. 1000.) then
-         strange = .true.
-         trigger='A'
-      elseif(Media(MediaNo).Z .lt. 1. .or.
-     *   Media(MediaNo).Z .gt. 1000.) then
-         strange = .true.
-         trigger='Z'
-      elseif(Media(MediaNo).Aeff .lt.  1.) then
-         strange = .true.
-         trigger='Aeff'
-      endif
-c
-      if(strange) then
-         if( Media(MediaNo).rhoc .ne.  1.) then
-            write(*,*) 'No rhoc correction included in the next'
-         endif
-         write(*,*) trigger, ' ***********', msg
-         write(*,*) ' code=',cTrack.p.code,' proc=',Move.proc
-         write(*,*) '      MediaNo=', MediaNo,
-     *      ' noOfElem=',Media(MediaNo).noOfElem
-         write(*,*)
-     *         ' charge=',cTrack.p.charge, ' subcode=',cTrack.p.subcode,
-     *         ' E=', cTrack.p.fm.p(4), ' Zeff=', Media(MediaNo).Zeff
-         write(*, *) ' noOfElem=', Media(MediaNo).noOfElem,
-     *         ' n, A, Z', Media(MediaNo).n,
-     *          Media(MediaNo).A, Media(MediaNo).Z
-         write(*,*)' mbtoPgrm=',Media(MediaNo).mbtoPgrm,
-     *         ' mbtoPcm=',Media(MediaNo).mbtoPcm,
-     *         ' mbtoPX0=',Media(MediaNo).mbtoPX0
-
-         write(*,*)' mbtoPgrm2=',Media(MediaNo).mbtoPgrm2,
-     *         ' mbtoPcm2=',Media(MediaNo).mbtoPcm2,
-     *          ' mbtoPX02=',Media(MediaNo).mbtoPX02
-
-         write(*,*)' Z2byAeff, Z5byA=', Media(MediaNo).Z2byAeff,
-     *         Media(MediaNo).Z5byAeff 
-
-
-         write(*,*)  ' A=', Media(MediaNo).A,
-     *           ' Z=', Media(MediaNo).Z,
-     *           ' Aeff=', Media(MediaNo).Aeff
-      endif
-      end
-c//////////
-      subroutine  debugpos(msg, compn, pos, icon)
-      implicit none
-#include "ZepTrackv.h"
-      record /epPos/ pos
-      character*(*) msg
-      integer compn, icon
-
-
-c////////////
-c      include 'Zdebug.h'
-c      if(dddd) then
-
-         write(*,*) '--------------- ', msg, ' Cn=',Cn
-         write(*,*) ' compn=',compn, ' pos.x,y,z=',
-     *      pos.x, pos.y,  pos.z
-         write(*,*) ' ctrackpos=',cTrack.pos.x, 
-     *      cTrack.pos.y, cTrack.pos.z, ' wx,y,z=',
-     *      cTrack.w.x, cTrack.w.y, cTrack.w.z
-         write(*,*) ' M-w.x =',Move.Track.w.x, 
-     *        Move.Track.w.y, Move.Track.w.z
-         write(*,*) ' Move.track.pos=',Move.Track.pos.x,
-     *     Move.Track.pos.y,  Move.Track.pos.z, ' dl=',
-     *     Move.dl, Move.dE, Move.Track.p.mass,
-     *    ' trucn=',Move.Trunc
-         write(*,*)
-     *     ' code=', cTrack.p.code,  ' chg=',cTrack.p.charge,
-     *     ' E=',  cTrack.p.fm.p(4)
-         write(*,*) ' cross=',Move.Cross, ' Trunc=',Move.Trunc
-         write(*,*) ' icon=',icon
-c      endif
-      end
       subroutine episoAngle( dir ) 
       implicit none
 #include "ZepDirec.h"      
@@ -2775,56 +2794,6 @@ c      endif
       endif
 
       end
-c//////////
-      subroutine  epfordebug(msg)
-      implicit none
-#include "ZepTrackv.h"
-      record /epPos/postemp
-      record /epDirec/ dirtemp
-      character*(*) msg  ! callers name is usually better
-      character(len=20) struc
-
-         write(0,*) '--------------- ', msg
-         write(0,*) ' ctrackpos=',cTrack.pos.x, 
-     *      cTrack.pos.y, cTrack.pos.z, ' wx,y,z=',
-     *      cTrack.w.x, cTrack.w.y, cTrack.w.z
-         write(0,*) ' M-w.x =',Move.Track.w.x, 
-     *        Move.Track.w.y, Move.Track.w.z
-         write(0,*) ' Move.track.pos=',Move.Track.pos.x,
-     *     Move.Track.pos.y,  Move.Track.pos.z, ' dl=',
-     *     Move.dl,' E and mass=', Move.dE, Move.Track.p.mass,
-     *    ' trucn=',Move.Trunc
-         write(0,*)
-     *     ' code=', cTrack.p.code,  ' chg=',cTrack.p.charge,
-     *     ' E=',  cTrack.p.fm.p(4), ' wl =',cTrack.wl
-         write(0,*) ' cross=',Move.Cross, ' Trunc=',Move.Trunc
-         write(0,*) ' cTrack.cn=',cTrack.cn, ' Move.cn=',
-     *    Move.track.cn, 'Cn=',Cn
-         write(0,*) ' media #=', MediaNo, ' media=', Media(MediaNo).name
-         call epqstruc(Cn, struc)
-         write(0,*) ' struc =', struc
-         write(0,*) ' Move.proc=', Move.proc
-c             world coord.
-
-         call epl2w(Cn, cTrack.pos, postemp)
-         call epl2wd(Cn, cTrack.w,  dirtemp)
-         write(0,*) ' assuming Cn=',Cn, ' world pos=',
-     *   postemp.x, postemp.y, postemp.z
-         write(0,*) ' dir=', dirtemp.x, dirtemp.y, dirtemp.z
-
-
-      end
-
-      subroutine epcurrent
-#include "ZepTrackp.h"
-#include "ZepTrackv.h"
-            write(*,*) ' now ground'
-            write(*,*) ' target A,Z=',Media(MediaNo).colA,
-     *         Media(MediaNo).colZ
-            write(*,*) ' code=',cTrack.p.code, ' chg=',
-     *                 cTrack.p.charge, ' sub=', cTrack.p.subcode,
-     *               ' Ek=',cTrack.p.fm.p(4)-cTrack.p.mass
-            end
 #if !defined (INTINFO)
 !          this is dummy routine to avoid link problem
 !      subroutine epUI(info, loc1, loc2)
@@ -2833,3 +2802,4 @@ c             world coord.
 !      integer,intent(in):: loc1,loc2
 !      end
 #endif
+
