@@ -51,10 +51,49 @@ c            read baisc parameters; find separater
                   call arprmr(vvalue, EminH)
                elseif( vname .eq. 'Es' ) then
                   call arprmr(vvalue, Escat)
-               elseif( vname .eq. 'EupperBndCS ') then
+               elseif( vname .eq. 'EupperBndCS') then
                   call arprmr(vvalue, EupperBndCS)
+               elseif( vname .eq. 'EpartialSC') then
+                  call arprmr(vvalue, EpartialSC)
+                  if( EpartialSC < 0.1d0 .or.
+     *                EpartialSC > 10.d0 ) then
+                     write(0,*) 'EpartialSC=',EpartialSC
+                     write(0,*) ' invalid in epicsfiel'
+                     write(0,*) ' must be 0.1~10 '
+                     stop
+                  endif        
+               elseif( vname == 'TargetElecBrems' ) then
+                  call arprmi(vvalue, TargetElecBrems)
+                  if( TargetElecBrems < 0 .or. TargetElecBrems >7 ) then
+                     write(0,*) 'TargetElecBrems=',TargetElecBrems,
+     *                 ' invalid'
+                     stop
+                  endif
+               elseif( vname .eq. 'Flpm') then
+                  call arprmr(vvalue, Flpm)
+                  if( Flpm < 1.0 ) then
+                     write(0,*) 'Flpm=',Flpm, ' invalid'
+                     write(0,*) 'must be >= 1 (<500)'
+                     stop
+                  elseif( Flpm > 500.) then
+                     write(0,*) 'Flpm=',Flpm, ' too large'
+                     write(0,*) ' normal range is 1~100'
+                     write(0,*) '======================'
+                     write(0,*) '======================'
+                     write(0,*) 
+     *               ' ***** Experimental purpose ?****'
+                     write(0,*) '======================'
+                     write(0,*) '======================'
+                  endif
+               elseif( vname .eq. 'HowNormBrems') then
+                  call arprmi(vvalue, HowNormBrems)
+               elseif( vname .eq. 'HowQuench') then
+                  call arprmi(vvalue, HowQuench)
                elseif( vname .eq. 'IncGp') then
-                  call arprmi(vvalue, IncGp)
+                  write(0,*) 'Sorry: IncGp is managed by param file'
+                  write(0,*) 
+     *       'If needed, use HowPhotoP(D=4)in &HPARAM part of param'
+                  stop
                elseif( vname .eq. 'IoTrace') then
                   call arprmi(vvalue, IoTrace)
                elseif( vname .eq. 'Knckon' ) then
@@ -143,9 +182,14 @@ c            read baisc parameters; find separater
                elseif( vname == "SrimEmax" ) then
                   call arprmr(vvalue, SrimEmax)
                elseif( vname == "PhitsXs" ) then
-                  call arprmi(vvalue, PhitsXs)
+                  write(0,*) 'PhitsXs is not used now'
+                  write(0,*) 'Please drop it from epicsfile'
+                  stop
                elseif( vname == "JamXs" ) then
-                  call arprmi(vvalue, JamXs)
+                  write(0,*) 'Sorry: JamXs is managed by param file'
+                  write(0,*) 
+     *       'If needed, put it(D=0) in &HPARAM part of param'
+                  stop
                else
                   write(0,*) ' epicsfile parameter: ', vname,
      *                 ' is undefined '
@@ -178,7 +222,12 @@ c      *************
             call awprmr(io,'EminH', EminH)
             call awprmr(io,'Es   ', Escat)
             call awprmr(io,'EupperBndCS ', EupperBndCS)
-            call awprmi(io,'IncGp', IncGp)
+            call awprmr(io,'EpartialSC ', EpartialSC)
+            call awprmi(io,'TargetElecBrems', TargetElecBrems)
+            call awprmr(io,'Flpm ', Flpm)
+            call awprmi(io,'HowNormBrems', HowNormBrems)
+            call awprmi(io,'HowQuench', HowQuench)
+!            call awprmi(io,'IncGp', IncGp)
             call awprmi(io,'IoTrace', IoTrace)
             call awprml(io,'Knckon', Knckon)
             call awprmi(io,'Molier', Moliere)
@@ -203,8 +252,8 @@ c      *************
             call awprmr(io, 'Excom2', Excom2)
             call awprml(io, 'LPMeffect', LPMeffect)
             call awprmi(io, 'StoppingPw', StoppingPw)
-            call awprmi(io, 'PhitsXs', PhitsXs)
-            call awprmi(io, 'JamXx', JamXs)
+!            call awprmi(io, 'PhitsXs', PhitsXs)
+!            call awprmi(io, 'JamXx', JamXs)
             do i = 1, MaxMediaDir
                call awprmc(io, 'MediaDir', MediaDir(i))
             enddo
@@ -235,10 +284,12 @@ c          truncation length shorter
           Tminx = Tmin/2
        endif
        if(KEmin .eq. 0.) then
-          KEmin = max(EminElec - masele, 20.d-3)  ! 20 MeV
+          KEmin = max(EminElec - masele, 100.d-6)  ! 100 keV
        endif
-       if( EminH == 0. ) then
-          EminH = max( KEmin, 20.d-3)   ! for nutron
+       if( EminH == 0. ) then  ! for neutron
+          EminH = 20.d-3
+       else
+          EminH = min( EminH, 20.d-3)  
        endif
        if( RecoilKEmin .eq. 0.) then
           RecoilKEmin =EminElec - masele
@@ -255,7 +306,19 @@ c           save;  to be used in epModify;  in GeV
        if( ModifyFile /= " " ) then  ! special modification requested
           call epfixModifier(ModifyFile)
        endif
-c        inform something to Cosmos
+c        get info from  Cosmos
        call epInfoPhotoP( IncGp )
-       call epInfoPhitsJamXs( PhitsXs, JamXs )
+! 
+!       call epInfoPhitsJamXs( PhitsXs, JamXs )
        end
+       subroutine epInfoPhotoP(gpinfo)
+   !    if this is placed in epcosIntF.f, epgen must be linked
+   !    which in tern requires ephook. So cannot be used
+   !   from other main.
+   !          copy the info for how to treat photo-had.prog
+   !          from cosmos: HowPhotoP
+      implicit none
+#include "Ztrackp.h"
+      integer,intent(out):: gpinfo
+      gpinfo = HowPhotoP
+      end
